@@ -1,9 +1,11 @@
 #ifndef CONFIG_DIALOG_H
 #define CONFIG_DIALOG_H
 
+
+#include <gtk/gtk.h>
+
 #include "search_dialog.h"
 #include "plugin.h"
-#include <gtk/gtk.h>
 
 #define OPTIONS_N 11
 
@@ -16,6 +18,10 @@ struct xfceweather_dialog {
         GtkWidget *dialog;
         GtkWidget *opt_unit;
         GtkWidget *txt_loc_code;
+        GtkWidget *txt_proxy_host;
+        GtkWidget *txt_proxy_port;
+        GtkWidget *chk_proxy_use;
+        GtkWidget *chk_proxy_fromenv;
 
         GtkWidget *tooltip_yes;
         GtkWidget *tooltip_no;
