@@ -1,17 +1,12 @@
 #ifndef PLUGIN_H
 #define PLUGIN_H
 
-#include "scrollbox.h"
-#include "parsers.h"
-#include "get_data.h"
-#include "http_client.h"
-#include "summary_window.h"
-#include "config_dialog.h"
-#include "icon.h"
-
 #include <panel/plugins.h>
 #include <gdk/gdk.h>
 
+#include "parsers.h"
+#include "get_data.h"
+
 #define XFCEWEATHER_ROOT "weather"
 #define DEFAULT_W_THEME "liquid"
 #define UPDATE_TIME 1800
@@ -35,6 +30,16 @@ struct xfceweather_data {
         enum units unit;
 
         struct xml_weather *weatherdata;
+
+        gchar *proxy_host;
+        gint proxy_port;
+
+        gboolean proxy_fromenv;
+        /* used for storing the configured 
+         * but not active proxy setttings */
+        gchar *saved_proxy_host;
+        gint saved_proxy_port;
 }; 
+gboolean check_envproxy(gchar **, gint *);
 
 #endif
