@@ -12,8 +12,12 @@ struct search_dialog {
         GtkListStore *result_mdl;
 
         gchar *result;
+
+        gchar *proxy_host;
+        gint proxy_port;
 };
 
-struct search_dialog *create_search_dialog(GtkWindow *);
+struct search_dialog *create_search_dialog(GtkWindow *, gchar *, gint);
 gboolean run_search_dialog(struct search_dialog *dialog);
 gchar *search_dialog_result(struct search_dialog *dialog);
+void free_search_dialog(struct search_dialog *dialog);
